package
Version:
v0.0.0-...-9cb7f86
Opens a new window with list of versions in this module.
Published: Jan 22, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Rand(max, lowest int) int
func Roll(sides, amount int) []int
Source Files
¶
Click to show internal directories.
Click to hide internal directories.